.. _modules-graph_creator:

###############
 Graph Creator
###############

This module is used to create custom graphs for data-driven weather
models. The graphs are built using a `recipe` that defines the structure
of the graph.

.. automodule:: anemoi.graphs.create
   :members:
   :no-undoc-members:
   :show-inheritance:
